function vect = kpp1d_child(r,d,x0,tout,tmat,bdd)
    %   work on kpp 1D
    %
    %   a core solver to be called by a parent MLX model
    %
    % Input:
    %       r    : reaction  param
    %       d    : diffusion param
    %       x0   : location of initial data
    %       tout : vector of times of the Output
    %       tmat : vecteur des temps de la DB
    %       bdd  : DB des N(t) qui va servir a l'interpolation
    %
    % Output:
    %      vect  : interpoled datas for r,d x0 and tout

    % rescaling
    s = sqrt(r*d);
    rr = (1e-4)*r/s;
    dd = (1e-4)*d/s;
    ww = dd/rr;
    %r,d,ww

    tout = tout*s/(1e-4);

    % ### number of time steps in the db
    nt = length(tmat);

    nval = sqrt(size(bdd,1));

    % ### The parameters to find
    XIN = [x0, ww];

    % ### Output
    sol = zeros(1,nt);

    % ### Projection si necessaire
    if ( (XIN(2)<6.25e-6) || (XIN(2)>1.9e-4) ...
            || (XIN(1)<0.) || (XIN(1)>1.)  )
        % projection sur le bord, version facile
        XIN(2) = max(XIN(2),6.25e-6);
        XIN(2) = min(XIN(2),1.9e-4);
        XIN(1) = max(XIN(1),0.);
        XIN(1) = min(XIN(1),1.); % puis methode classique dans la boite = copy/paste
    end
    %fprintf('%d',XIN);

    % ### on est dans la boite
    % ### on va chercher les 2^2 sommets qui entoure la donnee
    % ### La DB est triée par ordre croissant
    %     i = 1;
    xoTab = bdd(1:nval:end,1);
    wTab = bdd(1:nval,2);
    if (abs(XIN(1) - 1.) < 1.e-10)
        inds2 = (nval-1)*nval + 1;
        inds1 = inds2 - nval;
    else
        findx = find((xoTab > XIN(1)),1);
        inds2 = (findx-1)*nval + 1;
        inds1 = inds2 - nval;
    end
    if (abs(XIN(2) - 1.9e-4) < 1.e-10)
        findw = nval;
    else
        findw = find((wTab > XIN(2)),1);
    end
    ind2 = inds1 + findw - 1;
    ind1 = ind2 - 1;
    ind3 = ind1 + nval;
    ind4 = ind2 + nval;

    %     tgt = find(bdd(1:nval:size(bdd,1));
    %     while (XIN(1) > bdd(i,1))
    %        i = i + 1;
    %     end
    %     if (i > 1)
    %        indx0 = i-nval;
    %     else
    %        indx0 = 1;
    %     end
    %     j = 0;
    %     while (XIN(2) > bdd(indx0+j,2))
    %        j = j + 1;
    %     end
    %     indww = j-1;
    %
    %     ind1 = indx0 + indww;  % ### 1er sommet en bas à gauche
    %     ind2 = ind1 + 1; % ### 2eme sommet en haut à gauche
    %     ind3 = ind1 + nval; % ### 3eme sommet en bas à droite
    %     ind4 = ind3 + 1; % ### 4eme sommet en haut à droite
    %inds1, inds2, ind1,ind2,ind3,ind4

    % ### On fait d'abord l'interpolation sur les sommets
    % ### Les lignes de la matrices contenant les données de chacun
    % ### des sommets sont :
    %   bdd(ind1,3:)
    %   bdd(ind2,3:)
    %   bdd(ind3,3:)
    %   bdd(ind4,3:)

    % Proposition completement vectorisee, en 2D
    % Niveau B, reduction par interpol a x_1 fixe dans les param
    vxB1 = (bdd(ind3,1) - XIN(1))/(bdd(ind3,1) - bdd(ind1,1))...
        *bdd(ind1,3:end)...
        + (XIN(1) - bdd(ind1,1))/(bdd(ind3,1) - bdd(ind1,1))...
        *bdd(ind3,3:end);
    vxB2 = (bdd(ind3,1) - XIN(1))/(bdd(ind3,1) - bdd(ind1,1))...
        *bdd(ind2,3:end)...
        + (XIN(1) - bdd(ind1,1))/(bdd(ind3,1) - bdd(ind1,1))...
        *bdd(ind4,3:end);
    % Et enfin, le point voulu, a x_2 fixe
    sol = (bdd(ind4,2) - XIN(2))/(bdd(ind4,2) - bdd(ind3,2))*vxB1...
        + (XIN(2) - bdd(ind3,2))/(bdd(ind4,2) - bdd(ind3,2))*vxB2;

    % Version non optimale
    % for kt = 1:nt  % ### Pour tous les temps
    %     X1 = [bdd(ind1,1) bdd(ind3,1)];
    %     X2 = [bdd(ind1,2) bdd(ind2,2)];
    %     V = [bdd(ind1,kt+2) bdd(ind3,kt+2) ; bdd(ind2,kt+2) bdd(ind4,kt+2)];
    %     sol(1,kt) = interp2(X1,X2,V,XIN(1),XIN(2),'linear');
    % end


    % ### On fait l'interpolation sur le temps
    if (tout(end) <= tmat(end))
        vect = interp1(tmat,sol,tout);
    else
        vect = zeros(size(tout));
        target = find((tout>tmat(end)),1);
        vect(1:target-1) = interp1(tmat,sol,tout(1:target-1));
        vect(target:end) = vect(target-1)*ones(size(vect,1)-target+1,1);
    end

end
